pub fn is_enrolment_error(code: CreditRegistrationErrorCode) -> boolExpand description
The answers that would send the student off to enrol.
pub fn is_enrolment_error(code: CreditRegistrationErrorCode) -> boolThe answers that would send the student off to enrol.