pub fn settled_state(
endpoint: SuotarEndpoint,
code: &str,
) -> Option<CreditRegistrationState>Expand description
The state a code settles a row in, or None where it settles nothing.
pub fn settled_state(
endpoint: SuotarEndpoint,
code: &str,
) -> Option<CreditRegistrationState>The state a code settles a row in, or None where it settles nothing.