pub fn outcome_of(endpoint: SuotarEndpoint, code: &str) -> WireOutcomeExpand description
wire_outcome hardened for the endpoint the code arrived on. Every caller that has an
endpoint to name goes through here.
pub fn outcome_of(endpoint: SuotarEndpoint, code: &str) -> WireOutcomewire_outcome hardened for the endpoint the code arrived on. Every caller that has an
endpoint to name goes through here.