pub fn wire_code_retryability(code: &str) -> Option<Retryability>Expand description
The class the contract gives a wire code, before any hardening of ours, which is what the mock’s fault validator needs.
pub fn wire_code_retryability(code: &str) -> Option<Retryability>The class the contract gives a wire code, before any hardening of ours, which is what the mock’s fault validator needs.